/* $Id: riscos.h,v 1.4 2004/08/14 23:00:08 jonas Exp $ */

#ifndef EL__OSDEP_RISCOS_RISCOS_H
#define EL__OSDEP_RISCOS_RISCOS_H

#ifdef CONFIG_RISCOS

/* TODO */

#endif

#endif
